@@ -351,15 +351,15 @@ typedef struct _AtkStateSet               AtkStateSet;
  * @old_value: The old property value, NULL; in some contexts this value is undefined (see note below).
  * @new_value: The new value of the named property.
  *
- * @note: For most properties the old_value field of AtkPropertyValues will
- * not contain a valid value.
+ * Note: for most properties the old_value field of #AtkPropertyValues
+ * will not contain a valid value.
  *
  * Currently, the only property for which old_value is used is
  * accessible-state; for instance if there is a focus state the
  * property change handler will be called for the object which lost the focus
- * with the old_value containing an AtkState value corresponding to focused
+ * with the old_value containing an #AtkState value corresponding to focused
  * and the property change handler will be called for the object which
- * received the focus with the new_value containing an AtkState value
+ * received the focus with the new_value containing an #AtkState value
  * corresponding to focused.
  *
  **/
@@ -372,7 +372,7 @@ struct _AtkPropertyValues
 
 typedef struct _AtkPropertyValues        AtkPropertyValues;
 
-typedef gboolean (*AtkFunction)          (gpointer data); 
+typedef gboolean (*AtkFunction)          (gpointer user_data);
 /*
  * For most properties the old_value field of AtkPropertyValues will
  * not contain a valid value.
@@ -385,7 +385,7 @@ typedef gboolean (*AtkFunction)          (gpointer data);
  * received the focus with the new_value containing an AtkState value
  * corresponding to focused.
  */
-typedef void (*AtkPropertyChangeHandler) (AtkObject*, AtkPropertyValues*);
+typedef void (*AtkPropertyChangeHandler) (AtkObject* obj, AtkPropertyValues* vals);
 
 
 struct _AtkObject
